@@ -117,13 +117,21 @@ class BackupEngine {
             throw new Exception("Access denied to backup target");
         }
         
+        // Ensure database name is properly formatted and not empty
+        if (empty($database)) {
+            throw new Exception("Database name cannot be empty");
+        }
+        
+        // Log database backup creation for debugging
+        error_log("Creating database backup - User: $user, Database: $database, Target: $targetId");
+        
         $backupName = "{$user}_{$database}_db_" . date('Y-m-d_H-i-s');
         $tempFile = $this->tempDir . '/' . $backupName . '.sql.gz';
         $remotePath = "$user/databases/" . $backupName . '.sql.gz';
         
         // Create backup history record
         $history = new BackupHistory($this->db);
-        $history->create([
+        $result = $history->create([
             'target_id' => $targetId,
             'user' => $user,
             'backup_type' => 'database',
@@ -135,6 +143,10 @@ class BackupEngine {
             ]
         ]);
         
+        if (!$result) {
+            throw new Exception("Failed to create backup record");
+        }
+        
         // Trigger background processing
         $this->triggerBackgroundProcessing();
         
