@@ -175,7 +175,10 @@ $backupTargets = $stmt->fetchAll(PDO::FETCH_ASSOC);
                                             <?php endif; ?>
                                         </td>
                                         <td>
-                                            <span class="wp-version"><?php echo htmlspecialchars($site['wp_version'] ?? 'Unknown'); ?></span>
+                                            <span class="wp-version" data-site-id="<?php echo $site['id']; ?>">
+                                                <i class="fa fa-spinner fa-spin text-muted"></i>
+                                                <span class="text-muted">Loading...</span>
+                                            </span>
                                         </td>
                                         <td>
                                             <span class="badge bg-<?php echo $site['status'] === 'active' ? 'success' : 'warning'; ?>">
@@ -812,9 +815,74 @@ function escapeHtml(text) {
     return div.innerHTML;
 }
 
+// Function to load WordPress versions dynamically
+function loadWordPressVersions() {
+    // Collect all site IDs that need version checking
+    const versionElements = document.querySelectorAll('.wp-version[data-site-id]');
+    if (versionElements.length === 0) return;
+    
+    const siteIds = [];
+    versionElements.forEach(element => {
+        const siteId = element.dataset.siteId;
+        if (siteId) {
+            siteIds.push(siteId);
+        }
+    });
+    
+    if (siteIds.length === 0) return;
+    
+    // Fetch versions for all sites
+    const formData = new FormData();
+    formData.append('action', 'get_wordpress_versions');
+    siteIds.forEach(id => {
+        formData.append('site_ids[]', id);
+    });
+    
+    fetch('/api/wordpress-ajax.php', {
+        method: 'POST',
+        headers: {
+            'X-CSRF-Token': nonce
+        },
+        body: formData
+    })
+    .then(response => response.json())
+    .then(data => {
+        if (data.success && data.versions) {
+            // Update each version element
+            Object.keys(data.versions).forEach(siteId => {
+                const element = document.querySelector(`.wp-version[data-site-id="${siteId}"]`);
+                if (element) {
+                    const version = data.versions[siteId];
+                    if (version && version !== 'Unknown') {
+                        element.innerHTML = escapeHtml(version);
+                        element.classList.remove('text-muted');
+                    } else {
+                        element.innerHTML = '<span class="text-muted">Unknown</span>';
+                    }
+                }
+            });
+        } else {
+            // On error, set all to Unknown
+            versionElements.forEach(element => {
+                element.innerHTML = '<span class="text-muted">Unknown</span>';
+            });
+        }
+    })
+    .catch(error => {
+        console.error('Error loading WordPress versions:', error);
+        // On error, set all to Unknown
+        versionElements.forEach(element => {
+            element.innerHTML = '<span class="text-muted">Unknown</span>';
+        });
+    });
+}
+
 // Initialize when document is ready
 document.addEventListener('DOMContentLoaded', function() {
     console.log('WordPress page JavaScript loaded');
+    
+    // Load WordPress versions dynamically
+    loadWordPressVersions();
     // Site selection change handler
     document.getElementById('siteSelect').addEventListener('change', function() {
         const selectedOption = this.options[this.selectedIndex];
@@ -1726,13 +1794,37 @@ function pollUpdateStatus(updateId, siteId) {
             
             if (data.status === 'completed') {
                 showAlert('success', `WordPress updated successfully to version ${data.new_version}!`);
-                // Update the version display in the table
-                const siteRow = document.querySelector(`tr[data-site-id="${siteId}"]`);
-                if (siteRow) {
-                    const versionSpan = siteRow.querySelector('.wp-version');
-                    if (versionSpan) {
-                        versionSpan.textContent = data.new_version;
-                    }
+                // Reload the version for this specific site
+                const versionElement = document.querySelector(`.wp-version[data-site-id="${siteId}"]`);
+                if (versionElement) {
+                    // Show loading state
+                    versionElement.innerHTML = '<i class="fa fa-spinner fa-spin text-muted"></i> <span class="text-muted">Refreshing...</span>';
+                    
+                    // Fetch the updated version
+                    const formData = new FormData();
+                    formData.append('action', 'get_wordpress_versions');
+                    formData.append('site_ids[]', siteId);
+                    
+                    fetch('/api/wordpress-ajax.php', {
+                        method: 'POST',
+                        headers: {
+                            'X-CSRF-Token': nonce
+                        },
+                        body: formData
+                    })
+                    .then(response => response.json())
+                    .then(data => {
+                        if (data.success && data.versions && data.versions[siteId]) {
+                            versionElement.innerHTML = escapeHtml(data.versions[siteId]);
+                            versionElement.classList.remove('text-muted');
+                        } else {
+                            versionElement.innerHTML = '<span class="text-muted">Unknown</span>';
+                        }
+                    })
+                    .catch(error => {
+                        console.error('Error refreshing version:', error);
+                        versionElement.innerHTML = '<span class="text-muted">Unknown</span>';
+                    });
                 }
             } else if (data.status === 'failed') {
                 showAlert('danger', `WordPress update failed: ${data.error_message || 'Unknown error'}`);
